@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 BEGIN {
     require Time::Piece;
@@ -185,6 +185,57 @@ sub mysql_datetime {
     return $self->strftime("%Y-%m-%d %H:%M:%S");
 }
 
+sub add {
+    my ($self, @args) = @_;
+    return $self->SUPER::add(@args) if @args <= 1;
+
+    my %args = @args;
+    my $seconds = $self->_calc_seconds(%args);
+    $self = $self->SUPER::add($seconds);
+
+    $self = $self->add_months($args{months}) if $args{months};
+    $self = $self->add_years($args{years})   if $args{years};
+
+    $self;
+}
+
+sub subtract {
+    my ($self, @args) = @_;
+    return $self->SUPER::subtract(@args) if @args <= 1;
+
+    my %args = @args;
+    my $seconds = $self->_calc_seconds(%args);
+    $self = $self->SUPER::subtract($seconds);
+
+    $self = $self->add_months(-1 * $args{months}) if $args{months};
+    $self = $self->add_years(-1 * $args{years})   if $args{years};
+
+    $self;
+}
+
+sub _calc_seconds {
+    my $self = shift;
+
+    state $validator = Data::Validator->new(
+        seconds => {isa => 'Int', optional => 1},
+        minutes => {isa => 'Int', optional => 1},
+        hours   => {isa => 'Int', optional => 1},
+        days    => {isa => 'Int', optional => 1},
+        months  => {isa => 'Int', optional => 1},
+        years   => {isa => 'Int', optional => 1},
+    );
+    my $args = $validator->validate(@_);
+
+    my $seconds = 0;
+    $seconds += $args->{seconds}              if exists $args->{seconds};
+    $seconds += ONE_MINUTE * $args->{minutes} if exists $args->{minutes};
+    $seconds += ONE_HOUR   * $args->{hours}   if exists $args->{hours};
+    $seconds += ONE_DAY    * $args->{days}    if exists $args->{days};
+
+    $seconds;
+}
+
+
 1;
 __END__
 
@@ -226,6 +277,18 @@ Time::Piece::Plus - Subclass of Time::Piece with some useful method
   #default is localtime
   my $datetime       = Time::Piece::Plus->parse_mysql_datetime(str => "2011-11-26 23:28:50");
 
+  #calculete
+  my $date = localtime();
+  $date = $date->add(10);
+  $date = $date->add(Time::Seconds->new(10);
+  $date = $date->add(days => 1, hours => 12);
+  $date = $date + 3600;
+
+  $date = $date->subtract(10);
+  $date = $date->subtract(Time::Seconds->new(10);
+  $date = $date->subtrace(days => 1, hours => 12);
+  $date = $date - 3600;
+  $time_seconds = $date - Time::Piece::Plus->today;
 
 =head1 DESCRIPTION
 
@@ -280,13 +343,39 @@ Format MySQL DATE string like "YYYY-mm-dd HH:MM:SS".
 If you call a class method and returns the format now.
 Also, if called as an instance method returns the date and format of the instance.
 
+=head2 add(Int|Time::Seconds|Hash)
+
+=head2 subtract(Int|Time::Seconds|Time::Piece|Hash)
+
+Calculate and return new Time::Piece::Plus or Time::Seconds object using specified argument.
+If you specify Int, Time::Seconds or Time::Piece(::Plus)?, behavior is same as
+original Time::Piece. Operator overload is also available.
+
+If you specify Hash(not HashRef), behavior is similar to L<DateTime>'s these methods.
+But, they don't change object itself and returns new object.
+Available Hash keys are as follows, and Hash values are Int.
+
+=over
+
+=item seconds
+
+=item hours
+
+=item days
+
+=item months
+
+=item years
+
+=back
+
 =head1 AUTHOR
 
 Nishibayashi Takuji E<lt>takuji {at} senchan.jpE<gt>
 
 =head1 SEE ALSO
 
-L<Time::Piece>,L<Time::Piece::MySQL>
+L<Time::Piece>,L<Time::Piece::MySQL>,L<DateTime>
 
 =head1 LICENSE
 
